pub struct surd64 {
pub coef: r64,
pub radicand: u64,
}Expand description
Surd Type using 64 bit components - composed of a rational coefficient and a u32 radicand - i.e. for coefficient A and radicand B, this is A * sqrt(B); Cannot be Added or Subtracted, but can be multiplied and divided.
Fields
coef: r64Rational coefficient.
radicand: u64Radicand.
Implementations