pub struct VectorPrecise<const L: usize> {
pub data: [r32; L],
}Expand description
Vector type using rational components - allows for higher precision + implementation of Eq and Hash. Length of L, components are r32, indexable by usize index.
Fields
data: [r32; L]Array of r32 components.
Implementations
Sourceimpl<const L: usize> VectorPrecise<L>
impl<const L: usize> VectorPrecise<L>
Sourcepub fn new(data: [r32; L]) -> Self
pub fn new(data: [r32; L]) -> Self
Returns a new Vector of length L from an array of f32 with the same length.
Sourcepub fn dot(&self, other: VectorPrecise<L>) -> r32
pub fn dot(&self, other: VectorPrecise<L>) -> r32
Dot product with another Vector of same length.
Sourcepub fn as_row(&self) -> MatrixPrecise<1, L>
pub fn as_row(&self) -> MatrixPrecise<1, L>
Returns the Vector as a Matrix with 1 row and L columns - aka the Vector as a single row matrix.
Sourcepub fn as_col(&self) -> MatrixPrecise<L, 1>
pub fn as_col(&self) -> MatrixPrecise<L, 1>
Returns the Vector as a Matrix with L rows and 1 column - aka the Vector as a single column matrix.
Sourcepub fn vec_add(&self, other: Self) -> Self
pub fn vec_add(&self, other: Self) -> Self
Utility function for adding vectors - used to implement std::ops.
Sourcepub fn vec_mul(&self, other: Self) -> Self
pub fn vec_mul(&self, other: Self) -> Self
Utility function for multiplying vectors - used to implement std::ops.
Sourcepub fn rational_mul(&self, other: r32) -> Self
pub fn rational_mul(&self, other: r32) -> Self
Utility function for multiplying a vector by a rational - used to implement std::ops.
Sourcepub fn recip(&self) -> Self
pub fn recip(&self) -> Self
Utility function for getting the reciprocal of the vector, component wise - used to implement std::ops.
Sourcepub fn sq_sum(&self) -> r32
pub fn sq_sum(&self) -> r32
Returns the sum of the squared components of the vector, i.e. the squared magnitude of the vector.
Sourcepub fn normalised(&self) -> Self
pub fn normalised(&self) -> Self
Returns a normalised copy of the vector.